@@ -1,5 +1,5 @@
 package Test::Requires::Git;
-$Test::Requires::Git::VERSION = '1.001';
+$Test::Requires::Git::VERSION = '1.002';
 use strict;
 use warnings;
 
@@ -38,7 +38,6 @@ sub _version_gt {
 }
 
 my %check = (
-    version    => sub { $_[0] eq $_[1] },
     version_eq => sub { $_[0] eq $_[1] },
     version_ne => sub { $_[0] ne $_[1] },
     version_gt => sub { _version_gt(@_) },
@@ -47,6 +46,14 @@ my %check = (
     version_ge => sub { $_[0] eq $_[1] || _version_gt(@_) },
 );
 
+# aliases
+$check{'=='} = $check{eq} = $check{version} = $check{version_eq};
+$check{'!='} = $check{ne} = $check{version_ne};
+$check{'>'}  = $check{gt} = $check{version_gt};
+$check{'<='} = $check{le} = $check{version_le};
+$check{'<'}  = $check{lt} = $check{version_lt};
+$check{'>='} = $check{ge} = $check{version_ge};
+
 sub import {
     my $class = shift;
     my $caller = caller(0);
@@ -61,12 +68,14 @@ sub import {
     test_requires_git(@_) if @_;
 }
 
+sub _git_version { qx{git --version} }
+
 sub test_requires_git {
     my @spec = @_;
     croak 'Odd number of elements in git specification' if @spec % 2;
 
     # get the git version
-    my ($version) = qx{git --version} =~ /^git version (.*)/g;
+    my ($version) = __PACKAGE__->_git_version() =~ /^git version (.*)/g;
 
     # perform the check
     my ( $ok, $skip, $why ) = ( 1, 0, '' );
@@ -104,7 +113,14 @@ sub test_requires_git {
 
         # no plan declared yet
         elsif ( !defined $builder->has_plan ) {
-            $builder->skip_all($why);
+            if ( $builder->summary ) {
+                $builder->skip($why);
+                $builder->done_testing;
+                exit 0;
+            }
+            else {
+                $builder->skip_all($why);
+            }
         }
 
         # the plan is no_plan
@@ -115,7 +131,7 @@ sub test_requires_git {
 
         # some plan was declared, skip all tests one by one
         else {
-            $builder->skip($why) for 1 .. $builder->has_plan;
+            $builder->skip($why) for 1 + $builder->summary .. $builder->has_plan;
             exit 0;
         }
     }
@@ -172,15 +188,14 @@ If the checks fail, then all tests will be I<skipped>.
         ...;
     }
 
-Takes a list of version requirements (see L</GIT VERSION CHECKING> below),
-and I<skip> all tests if one of them does not pass.
-
-If the C<skip> parameter is given, only the specified number of tests will
-be skipped.
-
+Takes a list of version requirements (see L</GIT VERSION CHECKING>
+below), and if one of them does not pass, I<skips> all remaining tests.
 All conditions must be satisfied for the check to pass.
 
-If no condition is given, C<test_requires_git> will only check if C<git>
+When the C<skip> parameter is given, only the specified number of tests
+will be skipped.
+
+If no condition is given, C<test_requires_git> will simply check if C<git>
 is available.
 
 =head1 GIT VERSION CHECKING
@@ -190,41 +205,50 @@ The following version checks are currently supported.
 Note that versions C<1.0.0a> and C<1.0.0b> are respectively turned into
 C<1.0.1> and C<1.0.2> internally.
 
-=head2 version
-
 =head2 version_eq
 
-    test_requires_git version    => $version;
+Aliases: C<version_eq>, C<eq>, C<==>, C<version>.
+
     test_requires_git version_eq => $version;
 
 Passes if the current B<git> version is I<equal> to C<$version>.
 
 =head2 version_ne
 
+Aliases: C<version_ne>, C<ne>, C<!=>.
+
     test_requires_git version_eq => $version;
 
 Passes if the current B<git> version is I<not equal> to C<$version>.
 
 =head2 version_lt
 
+Aliases: C<version_lt>, C<lt>, C<E<lt>>.
+
     test_requires_git version_lt => $version;
 
 Passes if the current B<git> version is I<less than> C<$version>.
 
 =head2 version_gt
 
+Aliases: C<version_gt>, C<gt>, C<E<gt>>.
+
     test_requires_git version_gt => $version;
 
 Passes if the current B<git> version is I<greater than> C<$version>.
 
 =head2 version_le
 
+Aliases: C<version_le>, C<le>, C<E<lt>=>.
+
     test_requires_git version_le => $version;
 
 Passes if the current B<git> version is I<less than or equal> C<$version>.
 
 =head2 version_ge
 
+Aliases: C<version_ge>, C<ge>, C<E<gt>=>.
+
     test_requires_git version_ge => $version;
 
 Passes if the current B<git> version is I<greater than or equal > C<$version>.
